==> haskell-jira-wiki-markup-1.5.1-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-jira-wiki-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 jira-wiki-markup
version:              1.5.1
visibility:           public
id:                   jira-wiki-markup-1.5.1-I9jBzptS7We13zgajTGjFd
key:                  jira-wiki-markup-1.5.1-I9jBzptS7We13zgajTGjFd
license:              MIT
copyright:            © 2019–2023 Albert Krewinkel
maintainer:           tarleb@zeitkraut.de
author:               Albert Krewinkel
homepage:             https://github.com/tarleb/jira-wiki-markup
synopsis:             Handle Jira wiki markup
description:
    Parse jira wiki text into an abstract syntax tree for easy
    transformation to other formats.

category:             Text
abi:                  d1fba098c26b68c04beb6fce60f76bfd
exposed:              True
exposed-modules:
    Text.Jira.Markup Text.Jira.Parser Text.Jira.Parser.Block
    Text.Jira.Parser.Core Text.Jira.Parser.Inline
    Text.Jira.Parser.PlainText Text.Jira.Parser.Shared
    Text.Jira.Printer

import-dirs:          /usr/lib/ghc-9.4.8/site-local/jira-wiki-markup-1.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/jira-wiki-markup-1.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/jira-wiki-markup-1.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-jira-wiki-markup
hs-libraries:         HSjira-wiki-markup-1.5.1-I9jBzptS7We13zgajTGjFd
depends:              base-4.17.2.1 mtl-2.2.2 parsec-3.1.16.1 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-jira-wiki-markup/html/jira-wiki-markup.haddock

haddock-html:         /usr/share/doc/haskell-jira-wiki-markup/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-jira-wiki-markup-1.5.1-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-jira-wiki-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 jira-wiki-markup
version:              1.5.1
visibility:           public
id:                   jira-wiki-markup-1.5.1-JC0UxGnIW3NEKhHxzT4fQC
key:                  jira-wiki-markup-1.5.1-JC0UxGnIW3NEKhHxzT4fQC
license:              MIT
copyright:            © 2019–2023 Albert Krewinkel
maintainer:           tarleb@zeitkraut.de
author:               Albert Krewinkel
homepage:             https://github.com/tarleb/jira-wiki-markup
synopsis:             Handle Jira wiki markup
description:
    Parse jira wiki text into an abstract syntax tree for easy
    transformation to other formats.

category:             Text
abi:                  55e00f8580812c23ef75756775efb76a
exposed:              True
exposed-modules:
    Text.Jira.Markup Text.Jira.Parser Text.Jira.Parser.Block
    Text.Jira.Parser.Core Text.Jira.Parser.Inline
    Text.Jira.Parser.PlainText Text.Jira.Parser.Shared
    Text.Jira.Printer

import-dirs:          /usr/lib/ghc-9.4.8/site-local/jira-wiki-markup-1.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/jira-wiki-markup-1.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/jira-wiki-markup-1.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-jira-wiki-markup
hs-libraries:         HSjira-wiki-markup-1.5.1-JC0UxGnIW3NEKhHxzT4fQC
depends:              base-4.17.2.1 mtl-2.2.2 parsec-3.1.16.1 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-jira-wiki-markup/html/jira-wiki-markup.haddock

haddock-html:         /usr/share/doc/haskell-jira-wiki-markup/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
